Module contours

Module contours 

Re-exports

pub use shape_analysis::RotatedRect;
pub use shape_analysis::ShapeAnalysis;

Modules

shape_analysis

Structs

Contour
Represents a contour outline as a list of points.
ConvexityDefect
A convexity defect: the deepest point between two contour points and its convex hull.
Moments
Image moments representing spatial distribution.

Enums

RetrievalMode
Contour retrieval modes for hierarchy-based contour detection.