pub struct ConvexityDefect {
pub start: Point<f64>,
pub end: Point<f64>,
pub far_point: Point<f64>,
pub depth: f64,
}Expand description
A convexity defect: the deepest point between two contour points and its convex hull.
Fields
start: Point<f64>end: Point<f64>far_point: Point<f64>depth: f64Trait Implementations
Sourceimpl Clone for ConvexityDefect
impl Clone for ConvexityDefect
Sourcefn clone(&self) -> ConvexityDefect
fn clone(&self) -> ConvexityDefect
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ConvexityDefect
Sourceimpl Debug for ConvexityDefect
impl Debug for ConvexityDefect
Sourceimpl Default for ConvexityDefect
impl Default for ConvexityDefect
Sourcefn default() -> ConvexityDefect
fn default() -> ConvexityDefect
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ConvexityDefect
impl PartialEq for ConvexityDefect
Sourcefn eq(&self, other: &ConvexityDefect) -> bool
fn eq(&self, other: &ConvexityDefect) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ConvexityDefect