pub struct OnnxModel<B: Backend> {
pub model_path: String,
/* private fields */
}Expand description
Represents an imported or executed deep learning model.
Fields
model_path: StringImplementations
Sourceimpl<B: Backend> OnnxModel<B>
impl<B: Backend> OnnxModel<B>
Sourcepub fn load(path: impl AsRef<Path>, device: &B::Device) -> Result<Self>
pub fn load(path: impl AsRef<Path>, device: &B::Device) -> Result<Self>
Loads a neural network model from the specified file path.
Sourcepub fn predict_raw<const D1: usize, const D2: usize>(
&self,
input: Tensor<B, D1>,
) -> Result<Tensor<B, D2>>
pub fn predict_raw<const D1: usize, const D2: usize>( &self, input: Tensor<B, D1>, ) -> Result<Tensor<B, D2>>
Predicts/evaluates a raw input tensor, returning an output tensor.
Sourcepub fn preprocess(&self, image: &Image<B>) -> Result<Tensor<B, 4>>
pub fn preprocess(&self, image: &Image<B>) -> Result<Tensor<B, 4>>
Helper to convert a standardized image into a model-compatible input tensor of shape [1, C, H, W].