pub struct CameraCalibration;Implementations
Sourceimpl CameraCalibration
impl CameraCalibration
Sourcepub fn calibrate_camera(
object_points: &[Vec<Point<f64>>],
image_points: &[Vec<Point<f64>>],
_image_size: Size<usize>,
) -> Result<([[f64; 3]; 3], Vec<f64>)>
pub fn calibrate_camera( object_points: &[Vec<Point<f64>>], image_points: &[Vec<Point<f64>>], _image_size: Size<usize>, ) -> Result<([[f64; 3]; 3], Vec<f64>)>
Estimates the intrinsic camera matrix, distortion coefficients, and extrinsics.
Sourcepub fn project_points(
object_points: &[Point<f64>],
rvec: &[[f64; 3]; 3],
tvec: &[[f64; 3]; 1],
camera_matrix: &[[f64; 3]; 3],
dist_coeffs: &[f64],
) -> Result<Vec<Point<f64>>>
pub fn project_points( object_points: &[Point<f64>], rvec: &[[f64; 3]; 3], tvec: &[[f64; 3]; 1], camera_matrix: &[[f64; 3]; 3], dist_coeffs: &[f64], ) -> Result<Vec<Point<f64>>>
Projects 3D points onto the 2D image plane using intrinsic camera matrix and extrinsics.
Sourcepub fn find_homography(
src: &[Point<f64>],
dst: &[Point<f64>],
) -> Result<[[f64; 3]; 3]>
pub fn find_homography( src: &[Point<f64>], dst: &[Point<f64>], ) -> Result<[[f64; 3]; 3]>
Computes a 3x3 homography matrix mapping src to dst.
Sourcepub fn solve_pnp(
_object_points: &[Point<f64>],
_image_points: &[Point<f64>],
_camera_matrix: &[[f64; 3]; 3],
_dist_coeffs: &[f64],
) -> Result<([[f64; 3]; 3], [[f64; 3]; 1])>
pub fn solve_pnp( _object_points: &[Point<f64>], _image_points: &[Point<f64>], _camera_matrix: &[[f64; 3]; 3], _dist_coeffs: &[f64], ) -> Result<([[f64; 3]; 3], [[f64; 3]; 1])>
Solves Perspective-n-Point pose estimation problem.