Skip to main contentModule dnn
Source - OnnxModel
- Represents an imported or executed deep learning model.
- WeightLoader
- Helper class to load neural network weights from Safetensors and
PyTorch .bin formats.
- blob_from_image
- Creates a 4-dimensional blob tensor from an image with scaling, resizing, and channel mean subtraction.
- nms_boxes
- Non-maximum suppression for bounding boxes based on scores and
IoU threshold. - read_net
- Load network from files.
- read_net_from_onnx
- Load network specifically from ONNX format.