pub struct WeightLoader;Expand description
Helper class to load neural network weights from Safetensors and PyTorch .bin formats.
Implementations
Sourceimpl WeightLoader
impl WeightLoader
Sourcepub fn load_safetensors<B: Backend>(
path: impl AsRef<Path>,
device: &B::Device,
) -> Result<HashMap<String, Tensor<B, 2>>>
pub fn load_safetensors<B: Backend>( path: impl AsRef<Path>, device: &B::Device, ) -> Result<HashMap<String, Tensor<B, 2>>>
Loads weights from a .safetensors file and returns them as a vector of tensors.
Sourcepub fn load_bin<B: Backend>(
path: impl AsRef<Path>,
device: &B::Device,
expected_shape: [usize; 2],
) -> Result<Tensor<B, 2>>
pub fn load_bin<B: Backend>( path: impl AsRef<Path>, device: &B::Device, expected_shape: [usize; 2], ) -> Result<Tensor<B, 2>>
Loads weights from a PyTorch .bin file.
Standard PyTorch files are zip archives containing pickle formats.
In this native Rust remake, we provide a binary stream weight deserializer
that reads flat float streams, mimicking target weights layout.